% explosion.m
% fd, iacs, 9 janvier 2005, 25 fevrier 2025 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xlabel ('Integration de du/dt + u/tau = 0 par un schema d Euler explicite') ;
% title ('Cnam Paris. Travaux pratiques Iacs.') ;
%
tau=.045;
n=10;
dt=1/n
t=zeros(n+1,1);
u=zeros(n+1,1);
uex=zeros(n+1,1);
uex(1:1)=1;
u(1:1)=uex(1:1);
t(1:1)=0;
  for i=1:n;
t(i+1)=t(i)+dt;
u(i+1)=u(i) -dt*u(i)/tau;
uex(i+1)=exp(-t(i+1)/tau);
end ;
temps_final = t(n+1:n+1)

  
  plot( t,uex(:,1), 'b;solution exacte;' , t,u(:,1),'*;trajectoire numerique;', t,u(:,1),'k;;', t,uex(:,1)) ; 
axis ([ -.05   1.05   -10.1   10.1]) ;
title('explosion : pas de temps trop grand avec Euler explicite')
print -dpdf 01-explosion.pdf
print -djpg 01-explosion.jpg
