% reqhe.m
% Retour EQuilibre avec le schema de HEun
% fd, iacs, mai, 08 juillet 2004, 2, 9 janvier 2005, 25 fevrier 2025 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xlabel ('reqhe. Integration de du/dt + u = 0 par un schema de Heun') ;
% title ('Cnam Paris. Travaux pratiques Iacs.') ;
  n=3;
dt=1/n
t=zeros(n+1,1);
u=zeros(n+1,1);
ui=zeros(n+1,1);
uex=zeros(n+1,1);
uex(1:1)=1;
u(1:1)=uex(1:1);
u(1:1)=1;
t(1:1)=0;
  for i=1:n;
t(i+1)=t(i)+dt;
ui(i+1)=u(i) -dt*u(i);
u(i+1)=u(i) - 0.5 * dt * ( u(i) + ui(i+1) ) ;
uex(i+1)=exp(-t(i+1));
end ;


temps_final = t(n+1:n+1) 
plot( t,uex(:,1), 'b;solution exacte;' , t,u(:,1),'*;trajectoire numerique;', t,u(:,1),'k;;', t,uex(:,1)) ; 
axis ([ -.01   1.01   .3   1.05]) ;
title('integration de du/dt + u = 0 par un schema de Heun')
print -dpdf 05-reqhe.pdf
print -djpg 05-reqhe.jpg

