% pclier.m
% fd, iacs, 9 janvier  2005, 25 fevrier 2025
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xlabel ('pclier. Cycle limite ; precision du schema d Euler retrograde') ;
% title ('Cnam Paris. Travaux pratiques Iacs.') ;
m=8
pas=zeros(m,1);
err=zeros(m,1);
%
n=64 ; 
for j=1:m;
x=zeros(n+1,1); y=zeros(n+1,1);
x(1:1)=1; y(1:1)=0; dt=2*pi/n;
%          boucle en temps
for i=1:n;
x(i+1)= (x(i) - dt * y(i)) / (1+(dt*dt));
y(i+1)= (dt*x(i) + y(i)) / (1+(dt*dt)); end ;
% 
pas(j)=log(n)/log(2);
err(j)=log ( abs(x(n+1,1)-1) +  abs(y(n+1,1))) / log(2) ;
n=2*n; end;


%  calcul du coefficient avec une droite de regression
alpha=codre(m,pas,err)

plot(pas,err(:,1),'*;logarithme des ereurs;') ; 
axis ([ 5.8   13.2      -9.1     -1.1 ])  
title('cycle limite        Euler implicite : ordre 1')
print -dpdf 18-pclier.pdf
print -djpg 18-pclier.jpg

