% preqee.m
% fd, iacs, mai, 08 juillet 2004, 2, 9 janvier  2005, 25 fevrier 2025 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xlabel ('preqee. Precision du schema d Euler explicite') ;
% title ('Cnam Paris. Travaux pratiques Iacs.') ;
m=9
pas=zeros(m,1);
err=zeros(m,1);
%
  n=8;
  for j=1:m;
dt=1/n;
t=zeros(n+1,1);
u=zeros(n+1,1);
u;
u(1:1)=1;
t(1:1)=0;
  for i=1:n;
t(i+1)=t(i)+dt;
u(i+1)=u(i) -dt*u(i);
end ;
% plot(t,u(:,1),'*')
pas(j)=log(n)/log(2);
err(j)=log ( abs(u(n+1,1) - exp(-1)) ) / log(2) ;
n=2*n; end;

%
x=zeros(m,1); x =pas ;
y=zeros(m,1); y= err(:,1);
alpha=codre(m,x,y)


plot(pas,err(:,1),'*;logarithme des ereurs;') ; 
axis ([ 2.7 ,  11.3 ,  -14.1 , -4.9 ]) 
title('retour equilibre        Euler explicite : ordre 1')
print -dpdf 07-preqee.pdf
print -djpg 07-preqee.jpg



