% reqcn.m
% fd, iacs, mai, juillet 2004, 2 janvier 2005
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xlabel ('reqcn. Integration de du/dt + u = 0 par un schema de Crank Nicolson') ;
% title ('Cnam Paris. Travaux pratiques Iacs.') ;
%
n=3;
dt=1/n
t=zeros(n+1,1);
u=zeros(n+1,1);
uex=zeros(n+1,1);
uex(1:1)=1;
u(1:1)=uex(1:1);
t(1:1)=0;
  for i=1:n;
t(i+1)=t(i)+dt;
u(i+1)= (1-dt/2)*u(i) / (1+dt/2) ;
uex(i+1)=exp(-t(i+1));
end ;


temps_final = t(n+1:n+1) 
plot( t,uex(:,1), 'b;solution exacte;' , t,u(:,1),'*;trajectoire numerique;', t,u(:,1),'k;;', t,uex(:,1)) ; 
axis ([ -.01   1.01   .3   1.05]) ;
title('integration de du/dt + u = 0 par un schema de Crank Nicolson')
print -dpdf 04-reqcn.pdf
print -djpg 04-reqcn.jpg




